==> haskell-chunked-data-0.3.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.3.0
id: chunked-data-0.3.0-G7WJ5T5z8D4Gv8viwgHVmY
key: chunked-data-0.3.0-G7WJ5T5z8D4Gv8viwgHVmY
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Data.Builder Data.ChunkedZip Data.IOData
abi: 18e5d2487dbbee4acc3552165b40ff57
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/chunked-data-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/chunked-data-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/chunked-data-0.3.0
hs-libraries: HSchunked-data-0.3.0-G7WJ5T5z8D4Gv8viwgHVmY
depends:
    base-4.10.1.0 transformers-0.5.2.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj containers-0.5.10.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.3.1
id: chunked-data-0.3.1-812FvBQ3GdhAUDKwkCJB63
key: chunked-data-0.3.1-812FvBQ3GdhAUDKwkCJB63
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Typeclasses for dealing with various chunked data representations
description:
    See docs and README at <http://www.stackage.org/package/chunked-data>
category: Data
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Data.Builder Data.ChunkedZip Data.IOData
hidden-modules: Paths_chunked_data
abi: 9ee72bc62f2be0fdfff99f4918e264f6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/chunked-data-0.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/chunked-data-0.3.1
hs-libraries: HSchunked-data-0.3.1-812FvBQ3GdhAUDKwkCJB63
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
